@@ -1,9 +1,10 @@
 package BalanceOfPower::Commands;
-$BalanceOfPower::Commands::VERSION = '0.150000';
+$BalanceOfPower::Commands::VERSION = '0.200000';
 use v5.10;
 use Moo;
 use IO::Prompter;
 use Term::ANSIColor;
+use BalanceOfPower::Player;
 use BalanceOfPower::Executive;
 use BalanceOfPower::Constants ":all";
 use BalanceOfPower::Utils qw(next_turn prev_turn get_year_turns compare_turns evidence_text);
@@ -13,13 +14,6 @@ with 'BalanceOfPower::Role::Logger';
 has world => (
     is => 'ro'
 );
-has executive => (
-    is => 'ro',
-    default => sub { BalanceOfPower::Executive->new; },           
-    handles => { recognize_command => 'recognize_command',
-                 print_orders => 'print_orders'
-               }
-);
 has query => (
     is => 'rw',
     default => "" 
@@ -37,72 +31,101 @@ has active => (
     default => 1
 );
 
-sub init
+has active_player => (
+    is => 'rw',
+    default => ""
+);
+
+has executive => (
+    is => 'rw',
+);
+
+has latest_result => (
+    is => 'rw',
+);
+
+sub welcome
 {
     my $self = shift;
-    $self->executive->init($self->world);
-}
-
-
-
-
-
-
-sub init_game
-{
-    my $self = shift;
-    my $stubbed = shift;
-
     my $welcome_message = <<'WELCOME';
 Welcome to Balance of Power, simulation of a real dangerous world!
 
-Take the control of a country and try to make it the most powerful of the planet! 
+Hide in the darkness to gain power and richness while the world burn
 WELCOME
+    say $welcome_message;
+}
 
-    my $auto_years;
-    if($stubbed)
+sub set_auto_years
+{
+    my $self = shift;
+    my $auto_years = prompt "Tell a number of years to generate before game start: ", -i;
+    return $auto_years;
+}
+sub input_player
+{
+    my $self = shift;
+    my $player = prompt "Say your name, player: ";
+    if($player)
     {
-        $self->set_player_nation("Italy");
-        $self->world->player("PlayerOne");
-        $auto_years = 10;
+        $self->set_player($player);
     }
     else
     {
-        say $welcome_message;
-        my $player = prompt "Say your name, player: ";
-        my $player_nation = prompt "Select the nation you want to control: ", -menu=>$self->world->nation_names;
-        $self->world->player($player);
-        $self->set_player_nation($player_nation);
-        $auto_years = prompt "Tell a number of years to generate before game start: ", -i;
+        say "Bad entry";
     }
-    return $auto_years;
 }
-sub set_player_nation
+
+sub set_player
 {
     my $self = shift;
-    my $player_nation = shift;
-    $self->world->player_nation($player_nation);
-    $self->executive->actor($player_nation);
+    my $player = shift;
+    my $log_name = $player . ".log";
+    $log_name =~ s/ /_/g;
+    my $pl = BalanceOfPower::Player->new(name => $player, money => START_PLAYER_MONEY, log_name => $log_name);
+    $pl->delete_log();
+    $self->world->add_player($pl);
+    $self->active_player($player);
+}
+
+sub get_active_player
+{
+    my $self = shift;
+    return $self->world->get_player($self->active_player);
 }
 
 
 sub welcome_player
 {
     my $self = shift;
-    print $self->world->print_nation_actual_situation($self->world->player_nation);
-    print "\n";
+    #TODO: wallet situation will be printed
 }
 sub get_prompt_text
 {
     my $self = shift;
-    my $prompt_text = "[" . $self->world->player . ", leader of " . $self->world->player_nation . ". Turn is " . $self->world->current_year . "]\n";
-    my $nation  = $self->world->get_player_nation();
-    $prompt_text .= "Int:" . $nation->production_for_domestic . "    Exp:" . $nation->production_for_export . "    Prtg:" . $nation->prestige . "    Army:" . $nation->army . "\n";
-    if($self->world->order)
+    my $player = $self->world->get_player($self->active_player);
+    my $prompt_text = "";
+    my $controlled = undef;
+    my $ctrl_n = undef;
+    my $influence = undef;
+    if($self->executive)
     {
-        $prompt_text .= "=== ORDER SELECTED: " . $self->world->order . "\n";
+        $controlled = $self->executive->actor;
+        $ctrl_n = $self->world->get_nation($controlled);
+        $influence = $player->influence($controlled);
     }
-    $prompt_text .= $self->nation ? "(" . $self->nation . ") ?" : "?";
+     
+    $prompt_text = "[" . $player->name . ", Money: " . $player->money;
+    if($controlled)
+    {
+        $prompt_text .= ", Influence: $influence";
+    }
+    $prompt_text .= ". Turn is " . $self->world->current_year . "]\n";
+    if($controlled)
+    {
+        $prompt_text .= "Controlling $controlled (" . "Int:" . $ctrl_n->production_for_domestic . "    Exp:" . $ctrl_n->production_for_export . "    Prtg:" . $ctrl_n->prestige . "    Army:" . $ctrl_n->army . ")\n";
+        $prompt_text .= "Control orders: " .  $player->get_control_order($controlled) . "\n" if $player->get_control_order($controlled);
+    }
+    $prompt_text .= $self->nation ? "(" . $self->nation . " [" . $player->influence($self->nation) .  "]) ?" : "?";
     return $prompt_text;
 }
 
@@ -139,13 +162,22 @@ sub clear_query
     }
 }
 
+sub verify_nation
+{
+    my $self = shift;
+    my $query = shift;
+    return 0 if (! $query);
+    my @good_nation = grep { $query  =~ /^$_$/ } @{$self->world->nation_names};
+    return @good_nation > 0;
+}
+
 sub turn_command
 {
     my $self = shift;
     my $query = $self->query;
     if($query eq "turn")
     {
-        $self->nation(undef);
+        #$self->nation(undef);
         $self->query(undef);
         return { status => 1 };
     }
@@ -223,21 +255,10 @@ COMMANDS
         $self->nation(undef);
         $result = { status => 1 };
     }
-    elsif($query eq "clearorders")
-    {
-        $self->nation(undef);
-        $self->world->order(undef);
-        $result = { status => 1 };
-    }
     elsif($query eq "commands")
     {
         print $commands;
         $result = { status => 1 };
-    }
-     elsif($query eq "orders")
-    {
-        print $self->print_orders($self->world->player_nation);;
-        $result = { status => 1 };
     }
     elsif($query eq "wars")
     {
@@ -314,13 +335,15 @@ COMMANDS
         {
             $self->nation($input_nation);
         }
-        if(! $self->nation)
+        if($self->nation)
         {
-            $self->nation($self->world->player_nation);
+            print $self->world->print_borders_analysis($self->nation);
+            $result = { status => 1 };
+        }
+        else
+        {
+            $result = { status => -1 };
         }
-        #print $self->world->print_borders($self->nation);
-        print $self->world->print_borders_analysis($self->nation);
-        $result = { status => 1 };
     }
     elsif($query =~ /^((.*) )?near$/)
     {
@@ -329,13 +352,15 @@ COMMANDS
         {
             $self->nation($input_nation);
         }
-        if(! $self->nation)
+        if($self->nation)
         {
-            $self->nation($self->world->player_nation);
+            print $self->world->print_near_analysis($self->nation);
+            $result = { status => 1 };
+        }
+        else
+        {
+            $result = { status => -1 };
         }
-        #print $self->world->print_near_nations($self->nation);
-        print $self->world->print_near_analysis($self->nation);
-        $result = { status => 1 };
     }
     elsif($query =~ /^((.*) )?relations$/)
     {
@@ -344,12 +369,15 @@ COMMANDS
         {
             $self->nation($input_nation);
         }
-        if(! $self->nation)
+        if($self->nation)
         {
-            $self->nation($self->world->player_nation);
+            print $self->world->print_diplomacy($self->nation);
+            $result = { status => 1 };
+        }
+        else
+        {
+            $result = { status => -1 };
         }
-        print $self->world->print_diplomacy($self->nation);
-        $result = { status => 1 };
     }
     elsif($query =~ /^((.*) )?events( ((\d+)(\/\d+)?))?$/)
     {
@@ -360,10 +388,6 @@ COMMANDS
         {
             $self->nation($input_nation);
         }
-        if(! $self->nation)
-        {
-            $self->nation($self->world->player_nation);
-        }
         if($self->nation)
         {
             if($input_year)
@@ -390,6 +414,12 @@ COMMANDS
                 $self->keep_query(1);
                 $result = { status => 1 };
             } 
+            else
+            {
+                $query = prev_turn($self->world->current_year);
+                $self->keep_query(1);
+                $result = { status => 1 };
+            }
         }
     }
     elsif($query =~ /^((.*) )?status$/)
@@ -414,12 +444,15 @@ COMMANDS
         {
             $self->nation($input_nation);
         }
-        if(! $self->nation)
+        if($self->nation)
         {
-            $self->nation($self->world->player_nation);
+            print $self->world->print_nation_statistics($self->nation, $self->world->first_year, prev_turn($self->world->current_year));
+            $result = { status => 1 };
+        }
+        else
+        {
+            $result = { status => -1 };
         }
-        print $self->world->print_nation_statistics($self->nation, $self->world->first_year, prev_turn($self->world->current_year));
-        $result = { status => 1 };
     }
     elsif($query =~ /^((.*) )?plot (.*)$/)
     {
@@ -428,12 +461,15 @@ COMMANDS
         {
             $self->nation($input_nation);
         }
-        if(! $self->nation)
+        if($self->nation)
         {
-            $self->nation($self->world->player_nation);
+            print $self->world->plot_nation_factor($self->nation, $3, $self->world->first_year, prev_turn($self->world->current_year));
+            $result = { status => 1 };
+        }
+        else
+        {
+            $result = { status => -1 };
         }
-        print $self->world->plot_nation_factor($self->nation, $3, $self->world->first_year, prev_turn($self->world->current_year));
-        $result = { status => 1 };
     }
     else
     {
@@ -447,7 +483,7 @@ COMMANDS
         else
         {
             my @good_year = ();
-            if($query =~ /(\d+)(\/\d+)?/) #it's an year or a turn
+            if($query =~ /^(\d+)(\/\d+)?/) #it's an year or a turn
             {
                 if((compare_turns($query, $self->world->current_year) == 0 || compare_turns($query, $self->world->current_year) == -1) &&
                     compare_turns($query, $self->world->first_year) >= 0)
@@ -476,20 +512,233 @@ COMMANDS
     $self->query($query);
     return $result;
 }
-sub verify_nation
-{
-    my $self = shift;
-    my $query = shift;
-    return 0 if (! $query);
-    my @good_nation = grep { $query  =~ /^$_$/ } @{$self->world->nation_names};
-    return @good_nation > 0;
-}
+
 sub orders
 {
     my $self = shift;
-    return $self->recognize_command($self->nation,
-                                    $self->query);
-    
+    if($self->executive->actor)
+    {
+        if($self->get_active_player->influence($self->executive->actor) >= INFLUENCE_COST)
+        {
+            return $self->executive->recognize_command($self->nation,
+                                                       $self->query);
+        }
+        else
+        {
+            return { status => -4 };
+        }
+    }
+    else
+    {
+        return { status => 0 };
+    }
+}
+
+sub stock_commands
+{
+    my $self = shift;
+    my $query = $self->query;
+    my $result = { status => 0 };
+    $query = lc $query;
+    if($query =~ /^buy\s+(\d+)(\s+(.*))?$/)
+    {
+        my $stock_nation = $3;
+        if($stock_nation)
+        {
+            $stock_nation = $self->world->correct_nation_name($stock_nation);
+        }
+        else
+        {
+            $stock_nation = $self->nation;
+        }
+        my $q = $1;
+        if($stock_nation)
+        {
+            $result = $self->world->buy_stock($self->active_player, $stock_nation, $q, 1);
+            if($result->{ status } == 1)
+            {
+                $self->get_active_player()->add_stock_order($result->{ command });
+            }
+        }
+    } 
+    if($query =~ /^sell\s+(\d+)(\s+(.*))?$/)
+    {
+        my $stock_nation = $3;
+        if($stock_nation)
+        {
+            $stock_nation = $self->world->correct_nation_name($stock_nation);
+        }
+        else
+        {
+            $stock_nation = $self->nation;
+        }
+        my $q = $1;
+        if($stock_nation)
+        {
+            $result = $self->world->sell_stock($self->active_player, $stock_nation, $q, 1);
+            if($result->{ status } == 1)
+            {
+                $self->get_active_player()->add_stock_order($result->{ command });
+            }
+        }
+    } 
+    elsif($query eq 'market')
+    {
+        say $self->world->print_market;
+        $result = { status => 2 };
+    }
+    elsif($query eq 'show stocks')
+    {
+        say $self->world->print_stocks($self->active_player);
+        $result = { status => 2 };
+    }
+    elsif($query eq 'show stock orders')
+    {
+        my $player = $self->get_active_player;
+        say $player->print_stock_orders();
+        $result = { status => 2 };
+    }
+    elsif($query eq 'empty stock orders')
+    {
+        my $player = $self->get_active_player;
+        $player->empty_stock_orders();
+        $result = { status => 1 };
+    }
+    elsif($query =~ /^remove stock orders( (.*))?/)
+    {
+        my $stock_nation = $2;
+        if($stock_nation)
+        {
+            $stock_nation = $self->world->correct_nation_name($stock_nation);
+        }
+        else
+        {
+            $stock_nation = $self->nation;
+        }
+        if($stock_nation)
+        {
+            my $player = $self->get_active_player;
+            $player->remove_stock_orders($stock_nation);
+            $result = { status => 1 };
+        }
+    }
+    elsif($query =~ /^stockevents( ((\d+)(\/\d+)?))?$/)
+    {
+        my $input_year = $2;
+        $input_year ||= prev_turn($self->world->current_year);
+        my @turns = get_year_turns($input_year); 
+        foreach my $t (@turns)
+        {
+            print $self->world->print_stock_events($self->active_player, $t);
+            my $wait = prompt "... press enter to continue ...\n\n" if($t ne $turns[-1]);
+        }
+        print "\n";
+        $result = { status => 2 };
+    }
+
+    return $result;
+}
+
+sub control_commands
+{
+    my $self = shift;
+    my $query = $self->query;
+    my $result = { status => 0 };
+    $query = lc $query;
+    if($query =~ /^control( (.*))$/)
+    {
+        my $input_nation = $self->world->correct_nation_name($2);
+        my $controlled_nation = undef;
+        if($input_nation)
+        {
+            $controlled_nation = $input_nation;
+        }
+        if(! $controlled_nation)
+        {
+            $controlled_nation = $self->nation;
+        }
+        if($controlled_nation)
+        {
+            if($self->world->at_war($controlled_nation))
+            {
+                return { status => -2 };
+            }
+            if($self->world->at_civil_war($controlled_nation))
+            {
+                return { status => -3 };
+            }
+            my $player = $self->get_active_player();
+            if($player->influence($controlled_nation) > 0)
+            {
+                my $exec = BalanceOfPower::Executive->new;
+                $exec->init($self->world);
+                $exec->actor($controlled_nation);
+                $self->executive($exec);
+                say $self->world->print_nation_actual_situation($controlled_nation, 1);
+                $result = { status => 1 };
+            }
+            else
+            {
+                $result = { status => -1 };
+            }
+        }
+    }
+    elsif($query =~ /^uncontrol$/)
+    {
+        $self->executive(undef);
+        $result = { status => 1 };
+    }
+    elsif($query =~ /^show control orders/)
+    {
+        say $self->get_active_player->print_control_orders();
+        $result = { status => 1 }
+    }
+    elsif($query eq 'clearorders')
+    {
+        if($self->executive)
+        {
+            $self->get_active_player->add_control_order($self->executive->actor, undef);
+            $result = { status => 2 };
+        }
+    }
+    return $result;
+}
+
+sub commands
+{
+    my $self = shift;
+    my $result;
+    $result = $self->turn_command();
+    if($self->handle_result('turn', $result))
+    {
+        $self->latest_result($result);
+        return 1;
+    }
+    $result = $self->report_commands();
+    if($self->handle_result('report', $result))
+    {
+        $self->latest_result($result);
+        return 1;
+    }
+    $result = $self->stock_commands();
+    if($self->handle_result('stock', $result))
+    {
+        $self->latest_result($result);
+        return 1;
+    }
+    $result = $self->control_commands();
+    if($self->handle_result('control', $result))
+    {
+        $self->latest_result($result);
+        return 1;
+    }
+    $result = $self->orders();
+    if($self->handle_result('orders', $result))
+    {
+        $self->latest_result($result);
+        return 1;
+    }
+    return 0;
 }
 
 sub interact
@@ -503,36 +752,166 @@ sub interact
         my $result = undef;
         $self->clear_query();
         $self->get_query();
-        $result = $self->turn_command();
+        if(! $self->commands())
+        {
+            $self->latest_result(undef);
+            say "Bad command";
+        }
+    }
+}
+
+sub handle_result
+{
+    my $self = shift;
+    my $type = shift;
+    my $result = shift;
+    if($type eq 'turn')
+    {
         if($result->{status} == 1)
         {
             say "Elaborating " . $self->world->current_year . "...\n";
             $self->world->decisions();
             $self->world->post_decisions_elaborations();
-            say evidence_text($self->world->print_formatted_turn_events($self->world->current_year), $self->world->player_nation);
+            if($self->nation)
+            {
+                say evidence_text($self->world->print_formatted_turn_events($self->world->current_year), $self->nation);
+            }
+            else
+            {
+                say $self->world->print_formatted_turn_events($self->world->current_year);
+            }
             $self->world->pre_decisions_elaborations();
-            next;
+            $self->executive(undef);
+            return 1;
         }
-        $result = $self->report_commands();
-        next if($result->{status} == 1);
-        $result = $self->orders();
+        else
+        {
+            return 0;
+        }
+    }
+    elsif($type eq 'report')
+    {
+        if($result->{status} == 1) 
+        {
+            return 1;
+        }
+        elsif($result->{status} == -1)
+        {
+            say "No nation selected";
+            return 1;
+        } 
+        else
+        {
+            return 0;
+        }
+    }
+    elsif($type eq 'stock')
+    {
+        if($result->{status} == -11)
+        {
+            say "Requested stock quantity not available";
+            return 1;
+        }
+        elsif($result->{status} == -12)
+        {
+            say "Not enough money";
+            return 1;
+        }
+        elsif($result->{status} == -13)
+        {
+            say "You haven't that quantity";
+            return 1;
+        }
+        elsif($result->{status} == -14)
+        {
+            say "You can't trade during civil war";
+            return 1;
+        }
+        elsif($result->{status} == -15)
+        {
+            say "You can't buy more than " . MAX_BUY_STOCK .  " stocks";
+            return 1;
+        }
+        elsif($result->{status} == 1)
+        {
+            say "Stock order registered";
+            return 1;
+        }
+        elsif($result->{status} == 2)
+        {
+            return 1;
+        }
+        else
+        {
+            return 0;
+        }
+    }
+    elsif($type eq 'control')
+    {
+        if($result->{status} == 1)
+        {
+            return 1;
+        }
+        if($result->{status} == 2)
+        {
+            say "Order revoked";
+            return 1;
+        }
+        elsif($result->{status} == -1)
+        {
+            say "No influence on requested nation";
+            return 1;
+        }
+        elsif($result->{status} == -2)
+        {
+            say "No control during war";
+        }
+        elsif($result->{status} == -3)
+        {
+            say "No control during civil war";
+        }
+
+        else
+        {
+            return 0;
+        }
+    }
+    elsif($type eq 'orders')
+    {
         if($result->{status} == -1)
         {
             say "Command not allowed";
+            return 1;
         }
         elsif($result->{status} == -2)
         {
             say "No options available";
+            return 1;
         }
         elsif($result->{status} == -3)
         {
             say "Command aborted";
+            return 1;
+        }
+        elsif($result->{status} == -4)
+        {
+            say "Not enough influence";
+            return 1;
         }
         elsif($result->{status} == 1)
         {
-            say "Order selected: " . $result->{command};
-            $self->world->order($result->{command});
+            say "Order selected for " .
+                $self->executive->actor .  
+                ": " . $result->{command};
+            my $player = $self->get_active_player();
+            #$player->add_influence(-1 * INFLUENCE_COST, $self->executive->actor);
+            $player->add_control_order($self->executive->actor, $result->{command});
+            return 1;
         } 
+        else
+        {
+            return 0;
+        }
     }
 }
 
