@@ -1,5 +1,5 @@
 package BalanceOfPower::Commands::DiplomaticPressure;
-$BalanceOfPower::Commands::DiplomaticPressure::VERSION = '0.150000';
+$BalanceOfPower::Commands::DiplomaticPressure::VERSION = '0.200000';
 use Moo;
 
 extends 'BalanceOfPower::Commands::TargetNation';
@@ -20,6 +20,13 @@ sub IA
     my $self = shift;
     my $actor = $self->get_nation();
     my @hates = $self->world->shuffle("Choosing target for diplomatic pressure for ". $self->actor, $self->world->get_nations_with_status($self->actor, ['HATE']));
-    return "DIPLOMATIC PRESSURE ON " . $hates[0];
+    if(@hates)
+    {
+        return "DIPLOMATIC PRESSURE ON " . $hates[0];
+    }
+    else
+    {
+        return undef;
+    }
 }
 1;
