@@ -1,5 +1,5 @@
 package BalanceOfPower::Constants;
-$BalanceOfPower::Constants::VERSION = '0.150000';
+$BalanceOfPower::Constants::VERSION = '0.200000';
 use strict;
 use warnings;
 
@@ -73,6 +73,7 @@ use constant REBEL_ARMY_FOR_SUPPORT => 4;
 use constant SUPPORT_HELP_FOR_CIVIL_WAR => 7; 
 use constant REBEL_SUPPORT_HELP_FOR_CIVIL_WAR => 7; 
 use constant REBEL_SUPPORTER_WINNER_FRIENDSHIP => 90;
+use constant CIVIL_WAR_WEALTH_MALUS => 20;
 
 #War & domination
 use constant ARMY_FOR_BATTLE => 3;
@@ -106,6 +107,15 @@ use constant DOMINION_DIPLOMACY => 110;
 use constant ECONOMIC_AID_DIPLOMACY_FACTOR => 9;
 use constant MILITARY_AID_DIPLOMACY_FACTOR => 7;
 
+#Stock exchange
+use constant STOCK_INFLUENCE_FACTOR => .5;
+use constant START_STOCKS => [ 8, 10, 12 ];
+use constant START_PLAYER_MONEY => 1000;
+use constant WAR_BOND_COST => 10;
+use constant WAR_BOND_GAIN => 20;
+use constant INFLUENCE_COST => 1;
+use constant MAX_BUY_STOCK => 4;
+
 #Others
 use constant TRADEROUTE_SIZE_BONUS => .5;
 use constant PRODUCTION_UNITS => [ 2, 3, 4 ];
@@ -251,5 +261,13 @@ our @EXPORT_OK = ('MIN_EXPORT_QUOTE',
                   'TREATY_LIMIT_PROGRESS_STEP',
                   'TREATIES_FOR_PROGRESS_STEP',
                   'MAX_AFFORDABLE_PROGRESS',
+                  'STOCK_INFLUENCE_FACTOR',
+                  'START_STOCKS',
+                  'START_PLAYER_MONEY',
+                  'WAR_BOND_COST',
+                  'WAR_BOND_GAIN',
+                  'CIVIL_WAR_WEALTH_MALUS',
+                  'INFLUENCE_COST',
+                  'MAX_BUY_STOCK',
                 );
 our %EXPORT_TAGS = ( all => \@EXPORT_OK );
