@@ -1,5 +1,5 @@
 package BalanceOfPower::Executive;
-$BalanceOfPower::Executive::VERSION = '0.150000';
+$BalanceOfPower::Executive::VERSION = '0.200000';
 use strict;
 use v5.10;
 
@@ -8,7 +8,7 @@ use Moo;
 with 'BalanceOfPower::Role::Logger';
 
 use BalanceOfPower::Constants ":all";
-use BalanceOfPower::Utils qw(as_active);
+use BalanceOfPower::Utils qw(as_active as_title);
 use BalanceOfPower::Commands::BuildTroops;
 use BalanceOfPower::Commands::InMilitaryRange;
 use BalanceOfPower::Commands::DeleteRoute;
@@ -144,6 +144,7 @@ sub init
     $self->commands->{"RECALL REBEL MILITARY SUPPORT"} = $command; 
     $command =
         BalanceOfPower::Commands::MilitaryAid->new( name => "MILITARY AID FOR",
+                                                    synonyms => ["MILITARY AID"],
                                                     world => $world,
                                                     export_cost => MILITARY_AID_COST,
                                                   );
@@ -196,8 +197,9 @@ sub decide
     $c->actor($self->actor);
     if($c->allowed())
     {
-        $self->log($self->actor . ": executing $order");
         my $command = $c->IA();
+        my $exit_log = $command ? $command : "KO";
+        $self->log($self->actor . ": executing $order: $exit_log");
         return $command;  
     }
     else
@@ -210,7 +212,8 @@ sub decide
 sub print_orders
 {
     my $self = shift;
-    my $out = "";
+    my $out = as_title("ORDERS FOR " . $self->actor);
+    $out .= "\n\n";
     for(keys %{$self->commands})
     {
         my $c = $self->commands->{$_};
