@@ -1,5 +1,5 @@
 package BalanceOfPower::Nation;
-$BalanceOfPower::Nation::VERSION = '0.150000';
+$BalanceOfPower::Nation::VERSION = '0.200000';
 use strict;
 use v5.10;
 
@@ -10,11 +10,16 @@ use BalanceOfPower::Constants ':all';
 
 with 'BalanceOfPower::Role::Reporter';
 with 'BalanceOfPower::Nation::Role::IA';
+with 'BalanceOfPower::Nation::Role::Shareholder';
 
 has name => (
     is => 'ro',
     default => 'Dummyland'
 );
+has code => (
+    is => 'ro',
+    default => 'DUM'
+);
 has area => (
     is => 'ro',
     default => 'Neverwhere'
@@ -173,6 +178,12 @@ sub war_cost
     $self->add_wealth(-1 * WAR_WEALTH_MALUS);
     $self->register_event("WAR COST PAYED: " . WAR_WEALTH_MALUS);
 }
+sub civil_war_cost
+{
+    my $self = shift;
+    $self->add_wealth(-1 * CIVIL_WAR_WEALTH_MALUS);
+    $self->register_event("CIVIL WAR COST PAYED: " . CIVIL_WAR_WEALTH_MALUS);
+}
 
 sub boost_production
 {
@@ -425,6 +436,8 @@ sub win_civil_war
             $world->create_treaty($self->name, $rebel_supporter->name, 'alliance');
             $world->broadcast_event($self->name . " AND " . $rebel_supporter->name . " ARE NOW ALLIES. " . $rebel_supporter->name . " HELPED " . $self->name . " REVOLUTION", $self->name, $rebel_supporter->name);
         }
+        $world->empty_stocks($self->name);
+        $self->available_stocks(START_STOCKS->[$self->size]);
     }
     elsif($winner eq 'government')
     {
@@ -552,7 +565,7 @@ sub dump
     my $io = shift;
     my $indent = shift || "";
     print {$io} $indent . 
-                join(";", $self->name, $self->area, $self->export_quote, $self->government, $self->government_strength, $self->size, $self->internal_disorder, $self->production_for_domestic, $self->production_for_export, $self->prestige, $self->wealth, $self->debt, $self->rebel_provinces, $self->current_year, $self->army, $self->progress) . "\n";
+                join(";", $self->name, $self->code, $self->area, $self->export_quote, $self->government, $self->government_strength, $self->size, $self->internal_disorder, $self->production_for_domestic, $self->production_for_export, $self->prestige, $self->wealth, $self->debt, $self->rebel_provinces, $self->current_year, $self->army, $self->progress) . "\n";
     $self->dump_events($io, " " . $indent);
 }
 
@@ -563,10 +576,10 @@ sub load
     my $nation_line = ( split /\n/, $data )[0];
     $nation_line =~ s/^\s+//;
     chomp $nation_line;
-    my ($name, $area, $export_quote, $government, $government_strength, $size, $internal_disorder, $production_for_domestic, $production_for_export, $prestige, $wealth, $debt, $rebel_provinces, $current_year, $army, $progress) = split ";", $nation_line;
+    my ($name, $code, $area, $export_quote, $government, $government_strength, $size, $internal_disorder, $production_for_domestic, $production_for_export, $prestige, $wealth, $debt, $rebel_provinces, $current_year, $army, $progress) = split ";", $nation_line;
     $data =~ s/^.*?\n//;
     my $events = $self->load_events($data);
-    return $self->new(name => $name, area => $area, size => $size,
+    return $self->new(name => $name, code => $code, area => $area, size => $size,
                       export_quote => $export_quote, government => $government, government_strength => $government_strength,
                       internal_disorder => $internal_disorder, 
                       production_for_domestic => $production_for_domestic, production_for_export => $production_for_export,
