@@ -1,5 +1,5 @@
 package BalanceOfPower::World;
-$BalanceOfPower::World::VERSION = '0.150000';
+$BalanceOfPower::World::VERSION = '0.200000';
 use strict;
 use v5.10;
 
@@ -35,6 +35,10 @@ has nation_names => (
     is => 'rw',
     default => sub { [] }
 );
+has nation_codes => (
+    is => 'rw',
+    default => sub { {} }
+);
 has order => (
     is => 'rw',
     default => ""
@@ -76,17 +80,20 @@ has savefile => (
 );
 
 
-with 'BalanceOfPower::Role::Player';
+
+with 'BalanceOfPower::Role::GameMaster';
+with 'BalanceOfPower::Role::Historian';
 with 'BalanceOfPower::Role::Herald';
 with 'BalanceOfPower::Role::Ruler';
 with 'BalanceOfPower::Role::Mapmaker';
 with 'BalanceOfPower::Role::Supporter';
 with 'BalanceOfPower::Role::Diplomat';
 with 'BalanceOfPower::Role::Merchant';
+with 'BalanceOfPower::Role::Broker';
 with 'BalanceOfPower::Role::Warlord';
 with 'BalanceOfPower::Role::CrisisManager';
-with 'BalanceOfPower::Role::Historian';
 with 'BalanceOfPower::Role::Analyst';
+with 'BalanceOfPower::Role::Recorder';
 
 sub get_nation
 {
@@ -113,17 +120,13 @@ sub correct_nation_name
     my $self = shift;
     my $nation = shift;
     return undef if(! $nation);
+    $nation = $self->nation_codes->{uc $nation} if(exists $self->nation_codes->{uc $nation});
     for(@{$self->nation_names})
     {
         return $_ if(uc $_ eq uc $nation);
     }
     return undef;
 }
-sub get_player_nation
-{
-    my $self = shift;
-    return $self->get_nation($self->player_nation);
-}
 sub check_nation_name
 {
     my $self = shift;
@@ -150,7 +153,7 @@ sub load_nations_data
         chomp $n;
         if(! ($n =~ /^#/))
         {
-            my ($name, $size, $government) = split(',', $n);
+            my ($name, $code, $size, $government) = split(',', $n);
             if($government eq 'd')
             {
                 $government = 'democracy';
@@ -159,7 +162,8 @@ sub load_nations_data
             {
                 $government = 'dictatorship';
             }
-            $nations_data{$name} = { area => $area,
+            $nations_data{$name} = { code => $code,
+                                     area => $area,
                                      size => $size,
                                      government => $government ,
                                    }
@@ -213,14 +217,17 @@ sub init_random
         $executive->init($self);
         push @{$self->nations}, BalanceOfPower::Nation->new( 
             name => $n, 
+            code => $nations_data{$n}->{code},
             executive => $executive,
             area => $nations_data{$n}->{area}, 
             size => $nations_data{$n}->{size},
             government => $nations_data{$n}->{government},
             export_quote => $export_quote, 
             government_strength => $government_strength,
+            available_stocks => START_STOCKS->[$nations_data{$n}->{size}],
             log_name => $self->log_name,
             log_on_stdout => $self->log_on_stdout);
+        $self->nation_codes->{$nations_data{$n}->{code}} = $n;
     }
     $self->nation_names(\@nation_names);
     $self->load_borders($bordersfile);
@@ -260,12 +267,14 @@ sub pre_decisions_elaborations
     my $t = shift;
     $self->init_year($t);
     $self->war_current_year();
+    $self->player_current_year();
     $self->war_debts();
     $self->crisis_generator();
 }
 sub post_decisions_elaborations
 {
     my $self = shift;
+    $self->execute_stock_orders();
     $self->execute_decisions();
     $self->economy();
     $self->warfare();
@@ -491,44 +500,56 @@ sub execute_decisions
     my $self = shift;
     my @decisions = @{$self->ia_orders};
     my @route_adders = ();
-    foreach my $d (@decisions)
+    #foreach my $d (@decisions)
+    foreach my $n (@{$self->nation_names})
     {
-        if($d =~ /^(.*): DELETE TRADEROUTE (.*)->(.*)$/)
+        my $command = $self->control($n);
+        if(! $command)
         {
-            $self->delete_route($2, $3);
+            my @nation_orders = grep { $_ =~ /^$n: / } @decisions;           if(@nation_orders > 0)
+            {
+                $nation_orders[0] =~ /^(.*): (.*)$/;
+                $command = $2;
+            }
+            else
+            {
+                next;
+            }
         }
-        elsif($d =~ /^(.*): ADD ROUTE$/)
+        my $nation = $self->get_nation($n);
+        if($command =~ /^DELETE TRADEROUTE (.*)->(.*)$/)
         {
-            push @route_adders, $1;
+            $self->delete_route($1, $2);
         }
-        elsif($d =~ /^(.*): LOWER DISORDER$/)
+        elsif($command =~ /^ADD ROUTE$/)
+        {
+            push @route_adders, $nation->name;
+        }
+        elsif($command =~ /^LOWER DISORDER$/)
         {
-           my $nation = $self->get_nation($1);
            $nation->lower_disorder($self);
         }
-        elsif($d =~ /^(.*): BUILD TROOPS$/)
+        elsif($command =~ /^BUILD TROOPS$/)
         {
-           my $nation = $self->get_nation($1);
            $nation->build_troops();
         }
-        elsif($d =~ /^(.*): BOOST PRODUCTION$/)
+        elsif($command =~ /^BOOST PRODUCTION$/)
         {
-           my $nation = $self->get_nation($1);
            $nation->boost_production();
         }
-        elsif($d =~ /^(.*): DECLARE WAR TO (.*)$/)
+        elsif($command =~ /DECLARE WAR TO (.*)$/)
         {
-            my $attacker = $self->get_nation($1);
-            my $defender = $self->get_nation($2);
+            my $attacker = $nation;
+            my $defender = $self->get_nation($1);
             if(! $self->at_war($attacker->name) && ! $self->at_war($defender->name))
             {
                 $self->create_war($attacker, $defender);
             }
         }
-        elsif($d =~ /^(.*): MILITARY SUPPORT (.*)$/)
+        elsif($command =~ /^MILITARY SUPPORT (.*)$/)
         {
-            my $supporter = $self->get_nation($1);
-            my $supported = $self->get_nation($2);
+            my $supporter = $nation;
+            my $supported = $self->get_nation($1);
             if($supported->accept_military_support($supporter->name, $self))
             {
                 $self->start_military_support($supporter, $supported);
@@ -538,84 +559,85 @@ sub execute_decisions
                 $self->broadcast_event($supported->name . " REFUSED MILITARY SUPPORT FROM " . $supporter->name);
             }
         }
-        elsif($d =~ /^(.*): RECALL MILITARY SUPPORT (.*)$/)
+        elsif($command =~ /^RECALL MILITARY SUPPORT (.*)$/)
         {
-           my $supporter = $self->get_nation($1);
-           my $supported = $self->get_nation($2);
+           my $supporter = $nation;
+           my $supported = $self->get_nation($1);
            $self->stop_military_support($supporter, $supported);
         }
-        elsif($d =~ /^(.*): AID INSURGENTS IN (.*)$/)
+        elsif($command =~ /^AID INSURGENTS IN (.*)$/)
         {
-            my $attacker = $self->get_nation($1);
-            my $victim = $self->get_nation($2);
-            $self->aid_insurgents($attacker, $victim);
+            my $victim = $self->get_nation($1);
+            $self->aid_insurgents($nation, $victim);
         }
-        elsif($d =~ /^(.*): TREATY (.*) WITH (.*)$/)
+        elsif($command =~ /^TREATY (.*) WITH (.*)$/)
         {
-            my $nation1 = $self->get_nation($1);
-            my $nation2 = $self->get_nation($3);
-            $self->stipulate_treaty($nation1, $nation2, $2);
-        }
-        elsif($d =~ /^(.*): ECONOMIC AID FOR (.*)$/)
-        {
-            my $nation1 = $self->get_nation($1);
             my $nation2 = $self->get_nation($2);
-            $self->economic_aid($nation1, $nation2);
+            $self->stipulate_treaty($nation, $nation2, $1);
         }
-        elsif($d =~ /^(.*): REBEL MILITARY SUPPORT (.*)$/)
+        elsif($command =~ /^ECONOMIC AID FOR (.*)$/)
         {
-            my $nation1 = $self->get_nation($1);
-            my $nation2 = $self->get_nation($2);
+            my $nation2 = $self->get_nation($1);
+            $self->economic_aid($nation, $nation2);
+        }
+        elsif($command =~ /^REBEL MILITARY SUPPORT (.*)$/)
+        {
+            my $nation2 = $self->get_nation($1);
             my $rebsup = $self->rebel_supported($nation2->name);
-            if($rebsup && $rebsup->node1 ne $nation1->name)
+            if($rebsup && $rebsup->node1 ne $nation->name)
             {
-                $self->broadcast_event("REBEL SUPPORT IN " . $nation2->name . " IMPOSSIBLE FOR " . $nation1->name, $nation1->name, $nation2->name);
+                $self->broadcast_event("REBEL SUPPORT IN " . $nation2->name . " IMPOSSIBLE FOR " . $nation->name, $nation->name, $nation2->name);
             }
             else
             {
-                $self->start_rebel_military_support($nation1, $nation2);
+                $self->start_rebel_military_support($nation, $nation2);
             }
         }
-        elsif($d =~ /^(.*): DIPLOMATIC PRESSURE ON (.*)$/)
+        elsif($command =~ /^DIPLOMATIC PRESSURE ON (.*)$/)
         {
-            my $n1 = $1;
-            my $n2 = $2;
-            my $nation1 = $self->get_nation($n1);
-            if($nation1->prestige >= DIPLOMATIC_PRESSURE_PRESTIGE_COST)
+            my $n2 = $1;
+            if($nation->prestige >= DIPLOMATIC_PRESSURE_PRESTIGE_COST)
             {
                 my $under_infl = $self->is_under_influence($n2); 
                 $under_infl ||= "";
-                if($under_infl ne $n1)
+                if($under_infl ne $nation->name)
                 {
-                    $self->diplomatic_pressure($n1, $n2);
+                    $self->diplomatic_pressure($nation->name, $n2);
                 }
                 else
                 {
-                    $self->broadcast_event("DIPLOMATIC PRESSURE ON $n2 BY $n1 IMPOSSIBLE! $n2 IS UNDER INFLUENCE OF $n1", $n1, $n2);
+                    $self->broadcast_event("DIPLOMATIC PRESSURE ON $n2 BY " . $nation->name . " IMPOSSIBLE! $n2 IS UNDER INFLUENCE OF " . $nation->name, $nation->name, $n2);
                 }
             }
         }
-        elsif($d =~ /^(.*): RECALL REBEL MILITARY SUPPORT (.*)$/)
+        elsif($command =~ /^RECALL REBEL MILITARY SUPPORT (.*)$/)
         {
-           my $supporter = $self->get_nation($1);
-           my $supported = $self->get_nation($2);
-           $self->stop_rebel_military_support($supporter, $supported);
+           my $supported = $self->get_nation($1);
+           $self->stop_rebel_military_support($nation, $supported);
         }
-        elsif($d =~ /^(.*): MILITARY AID FOR (.*)$/)
+        elsif($command =~ /^MILITARY AID FOR (.*)$/)
         {
-            my $nation1 = $self->get_nation($1);
-            my $nation2 = $self->get_nation($2);
-            $self->military_aid($nation1, $nation2);
+            my $nation2 = $self->get_nation($1);
+            $self->military_aid($nation, $nation2);
         }
-        elsif($d =~ /^(.*): PROGRESS$/)
+        elsif($command =~ /^PROGRESS$/)
         {
-            my $nation =  $self->get_nation($1);
             $nation->grow();
             $self->broadcast_event("INVESTMENT IN PROGRESS FOR " . $nation->name, $nation->name);
         }
+        $self->set_statistics_value($nation, 'order', $command);
     }
+    $self->empty_control_orders();
     $self->manage_route_adding(@route_adders);
 }
+sub empty_control_orders
+{
+    my $self = shift;
+    foreach my $p (@{$self->players})
+    {
+       $p->empty_control_orders(); 
+    }
+}
 
 sub manage_route_adding
 {
@@ -669,18 +691,7 @@ sub decisions
     foreach my $nation (@{$self->nations})
     {
         my $decision;
-        if($nation->name eq $self->player_nation && ! $self->autoplay)
-        {
-            if($self->order)
-            {
-                $decision = $nation->name . ": " . $self->order;
-                $self->order(undef);
-            }
-        }
-        else
-        {
-            $decision = $nation->decision($self);
-        }
+        $decision = $nation->decision($self);
         if($decision)
         {
             push @decisions, $decision;
@@ -688,6 +699,50 @@ sub decisions
     }
     $self->ia_orders(\@decisions);
 }
+sub control
+{
+    my $self =  shift;
+    my $nation = shift;
+    my $quote = -1;
+    my $winner = undef;
+    my @losers = ();
+    my $winner_command;
+    foreach my $player (@{$self->players})
+    {
+        my $player_command = $player->get_control_order($nation);
+        if($player_command)
+        {
+            $player->add_influence(-1 * INFLUENCE_COST, $nation);
+            if($player->stocks($nation) > $quote)
+            {
+                if($winner)
+                {
+                    push @losers, $winner;
+                }
+                $winner = $player;
+                $quote = $player->stocks($nation);
+                $winner_command = $player_command;
+            }
+            else
+            {
+                push @losers, $player;
+            }
+        }
+    }
+    if($winner)
+    {
+        $winner->register_event("ORDER FOR $nation IS EXECUTED: $winner_command");
+        for(@losers)
+        {
+            $_->register_event("ORDER FOR $nation NOT EXECUTED! " . $winner->name . " MORE POWERFUL");
+        }
+        return $winner_command;
+    }
+    else
+    {
+        return undef;
+    }
+}
 
 # DECISIONS END ###########################################################
 
@@ -708,6 +763,10 @@ sub economy
         {
             $n->war_cost();
         }
+        if($self->at_civil_war($n->name))
+        {
+            $n->civil_war_cost();
+        }
 
         my $wealth = $n->wealth;
         my $pu = PRODUCTION_UNITS->[$n->size];
@@ -938,174 +997,7 @@ sub build_commands
 {
     my $self = shift;
     my $commands = BalanceOfPower::Commands->new( world => $self, log_name => 'bop-commands.log', log_active => $self->log_active );
-    $commands->init($self);
     return $commands;
 }
 
-sub dump
-{
-    my $self = shift;
-    my $io = shift;
-    my $indent = shift || "";
-    print {$io} $indent . join(";", $self->name, $self->first_year, $self->current_year, $self->player, $self->player_nation) . "\n";
-    $self->dump_events($io, " " . $indent);
-}
-sub load
-{
-    my $self = shift;
-    my $data = shift;
-    my $world_line = ( split /\n/, $data )[0];
-    $world_line =~ s/^\s+//;
-    chomp $world_line;
-    my ($name, $first_year, $current_year, $player, $player_nation) =
-        split ";", $world_line;
-    $data =~ s/^.*?\n//;
-    my $events = $self->load_events($data);
-    return BalanceOfPower::World->new(name => $name, 
-                                      first_year => $first_year, current_year => $current_year,
-                                      player => $player, player_nation => $player_nation,
-                                      events => $events);
-}
-
-sub load_nations
-{
-    my $self = shift;
-    my $data = shift;
-    $data .= "EOF\n";
-    my $nation_data = "";
-    foreach my $l (split "\n", $data)
-    {
-
-        if($l !~ /^\s/)
-        {
-            if($nation_data)
-            {
-                my $nation = BalanceOfPower::Nation->load($nation_data);
-                my $executive = BalanceOfPower::Executive->new( actor => $nation->name );
-                $executive->init($self);
-                $nation->executive($executive);
-                push @{$self->nations}, $nation;
-                push @{$self->nation_names}, $nation->name;
-            }
-            $nation_data = $l . "\n";
-        }
-        else
-        {
-            $nation_data .= $l . "\n";
-        }
-    }
-}
-
-sub dump_all
-{
-    my $self = shift;
-    my $file = shift;
-    return "No file provided" if ! $file;
-    open(my $io, "> $file");
-    $self->dump($io);
-    print {$io} "### NATIONS\n";
-    for(@{$self->nations})
-    {
-        $_->dump($io);
-    }
-    print {$io} "### DIPLOMATIC RELATIONS\n";
-    $self->diplomatic_relations->dump($io);
-    print {$io} "### TREATIES\n";
-    $self->treaties->dump($io);
-    print {$io} "### BORDERS\n";
-    $self->borders->dump($io);
-    print {$io} "### TRADEROUTES\n";
-    $self->trade_routes->dump($io);
-    print {$io} "### INFLUENCES\n";
-    $self->influences->dump($io);
-    print {$io} "### SUPPORTS\n";
-    $self->military_supports->dump($io);
-    print {$io} "### REBEL SUPPORTS\n";
-    $self->rebel_military_supports->dump($io);
-    print {$io} "### WARS\n";
-    $self->wars->dump($io);
-    print {$io} "### MEMORIAL\n";
-    $self->dump_memorial($io);
-    print {$io} "### STATISTICS\n";
-    $self->dump_statistics($io);
-    print {$io} "### EOF\n";
-    close($io);
-    return "World saved to $file";
-}   
-
-sub load_world
-{
-    my $self = shift;
-    my $file = shift;
-    open(my $dump, "<", $file) or die "Problems opening $file: $!";
-    my $world;
-    my $target = "WORLD";
-    my $data = "";
-    for(<$dump>)
-    {
-        my $line = $_;
-        if($line =~ /^### (.*)$/)
-        {
-            my $next = $1;
-            if($target eq 'WORLD')
-            {
-                $world = $self->load($data);
-            }
-            elsif($target eq 'NATIONS')
-            {
-                $world->load_nations($data);
-            }
-            elsif($target eq 'DIPLOMATIC RELATIONS')
-            {
-                $world->diplomatic_relations->load_pack("BalanceOfPower::Relations::Friendship", $data);
-            }
-            elsif($target eq 'TREATIES')
-            {
-                $world->treaties->load_pack("BalanceOfPower::Relations::Treaty", $data);
-            }
-            elsif($target eq 'BORDERS')
-            {
-                $world->borders->load_pack("BalanceOfPower::Relations::Border", $data);
-            }
-            elsif($target eq 'TRADEROUTES')
-            {
-                $world->trade_routes->load_pack("BalanceOfPower::Relations::TradeRoute", $data);
-            }
-            elsif($target eq 'INFLUENCES')
-            {
-                $world->influences->load_pack("BalanceOfPower::Relations::Influence", $data);
-            }
-            elsif($target eq 'SUPPORTS')
-            {
-                $world->military_supports->load_pack("BalanceOfPower::Relations::MilitarySupport", $data);
-            }
-            elsif($target eq 'REBEL SUPPORTS')
-            {
-                $world->rebel_military_supports->load_pack("BalanceOfPower::Relations::MilitarySupport", $data);
-            }
-            elsif($target eq 'WARS')
-            {
-                $world->wars->load_pack("BalanceOfPower::Relations::War", $data);
-            }
-            elsif($target eq 'MEMORIAL')
-            {
-                $world->memorial($world->load_memorial($data));
-            }
-            elsif($target eq 'STATISTICS')
-            {
-                $world->load_statistics($data);
-            }
-            $data = "";
-            $target = $next;
-        }
-        else
-        {
-            $data .= $line;
-        }
-    }
-    close($dump);
-    return $world;
-}
-
-
 1;
